.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _presentation-extensibility:

Community and extensibility
===========================

Who can use canary?
-------------------

- Developers, scientists, and engineers working on software for HPC and beyond.

Customizing canary
------------------

- How to write plugins and adapt canary for specialized workflows.

Open source contributions
-------------------------

- Encouraging community involvement and plugin development.
